#
# spec file for package mint-themes
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   mint
Name:           mint-themes
Version:        2.0.8
Release:        1.6
Summary:        Mint Themes
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxmint/mint-themes
Source:         http://packages.linuxmint.com/pool/main/m/mint-themes/%{name}_%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  python3
BuildRequires:  rubygem(sass)
BuildArch:      noarch

%description
A collection of Mint GTK+ themes.

%package -n metatheme-%{_name}-common
Summary:        Mint Themes -- Common Files
Group:          System/GUI/Other
Recommends:     mint-x-icon-theme
Recommends:     mint-y-icon-theme
Suggests:       gtk2-metatheme-%{_name}
Suggests:       gtk3-metatheme-%{_name}
Provides:       %{_name}-themes = %{version}
Obsoletes:      %{_name}-themes < %{version}
# cinnamon-themes was last used in openSUSE Leap 42.3.
Provides:       cinnamon-themes = 2018.02.08
Obsoletes:      cinnamon-themes < 2018.02.08

%description -n metatheme-%{_name}-common
A collection of Mint GTK+ themes.

%package -n gtk2-metatheme-%{_name}
Summary:        Mint Themes -- GTK+ 2 Support
Group:          System/GUI/Other
Requires:       gtk2-engine-murrine
Requires:       metatheme-%{_name}-common = %{version}
Supplements:    packageand(metatheme-%{_name}-common:gtk2)

%description -n gtk2-metatheme-%{_name}
A collection of Mint GTK+ themes.

%package -n gtk3-metatheme-%{_name}
Summary:        Mint Themes -- GTK+ 3 Support
Group:          System/GUI/Other
Requires:       metatheme-%{_name}-common
Supplements:    packageand(metatheme-%{_name}-common:gtk3)
Provides:       %{_name}-themes-gtk3 = %{version}
Obsoletes:      %{_name}-themes-gtk3 < %{version}

%description -n gtk3-metatheme-%{_name}
A collection of Mint GTK+ themes.

%prep
%setup -q -n %{name}

%build
make %{?_smp_mflags} V=1

%install
mkdir -p %{buildroot}%{_datadir}/
cp -a .%{_datadir}/themes/ %{buildroot}%{_datadir}/themes/

%fdupes %{buildroot}%{_datadir}/themes/

%files -n metatheme-%{_name}-common
%license debian/copyright
%doc debian/changelog
%{_datadir}/themes/Mint*/
%exclude %{_datadir}/themes/Mint*/gtk-?.0/
"%{_datadir}/themes/Linux Mint/"

%files -n gtk2-metatheme-%{_name}
%{_datadir}/themes/Mint*/gtk-2.0/

%files -n gtk3-metatheme-%{_name}
%{_datadir}/themes/Mint*/gtk-3.0/

%changelog
* Sun Jan 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.8:
  * fix header bar size, e.g. for disk tool
  * Fix corner bar - only highlight the bar, not the applet, give it its own
    colors, fix the separator applet under the light theme.#
  * Fix GtkScale value position and mark length.
  * Mint-X - gtk3: Restore :disabled state to infobar buttons.
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.7:
  * Cinnamon: Add support for the cornerbar applet.
  * Cinnamon: Don't use the accent color for the panel-launcher hover state.
  * GTK-4 directory and assets added in update-variations.py script (#401)
  * Remove Mint-Y-Colors directory
  * Remove hardcoded hover and pressed colors
  * Rebuild generated files
  * Soften light Cinnamon colors
  * Remove accents in parts of the Cinnamon theme
  * Generate CSS
  * Update Pink
  * Update Aqua, Orange, Purple, Red, Sand, Teal
  * Update Blue and Grey
  * Update Green
  * Update Gtk3 thumbnails
  * Update dark Gtk3 thumbnails
  * Gtk2: Remove menubar-toolbar asset overrides
  * Update Cinnamon thumbnails
  * Mint-X: Update Cinnamon thumbnails
  * Linux Mint: Update cinnamon thumbnail
  * Update Gtk3 thumbnails
  * Cinnamon: Add support for the cinnamon locate pointer
  * Mint-X: Always use green for suggested-action buttons
  * Mint-Y-Gtk4: Fix rounded corners on maximized windows
  * Mint-X-Gtk4: Fix the suggested_bg_color variable
  * Mint-Y-Gtk4: Fix treeview line colors
  * Mint-Y-Gtk4: Improve dialog button styling
  * Mint-Y-Gtk3: Fix dragging in the Nemo sidebar
  * All Cinnamon: Fix artifacts in Main menu scrollview
  * Mint-Y-Gtk3: Better match spacing between ssd and non ssd titlebar buttons
  * Mint-Y: Add initial support for Gtk4
  * Mint-Y-Gtk3: Improve the styling of GtkCalendar
  * Mint-Y-Xfwm: Better match csd and non-csd titlebar font colors
  * Mint-X-Gtk3: Remove the 1px margin on xfce panel buttons
  * Mint-Y-Gtk3: Fix context menu label colors in Seahorse
  * Mint-Y-Gtk3: Set a color for spinbuttons
  * Mint-Y-Gtk3: Fix the color of treeview grid and tree lines
  * Mint-Y-Gtk2: Clean up an issue in Qt entries
  * Mint-X-Gtk3: Port the gtk3 theme to sass
* Sat Nov 27 2021 andy great <andythe_great@pm.me>
- Update to version 1.8.9.
  * Mint-Y-Gtk2: Put separators in menus
  * Gtk3: Better match csd and ssd window shadows
  * Mint-X-Gtk3: Add styling for app-notification
  * test-mint-y: Add a couple more things
  * Mint-Y: Remove the -darker variation
  * Mint-Y: Add a dark variant to the light theme
  * Mint-Y: Only ship a single metacity theme
  * Mint-Y: Force the metacity theme to update on gtk theme changes
  * Mint-Y-Cinnamon: Set a height for the run dialog entry
  * Mint-Y: Use a light sidebar in file managers
  * Mint-Y-Cinnamon: Give the light theme a light panel
  * Mint-Y: Restyle the window decorations
  * Mint-Y: Missed including a new icon for metacity
  * Mint-Y-Gtk3: Fix osd colors
  * Mint-Y: Tint the entire theme with the selected_bg_color
  * Mint-Y: Add rounded corners to the window borders
  * Mint-Y: Adjust csd window shadows again
  * Mint-Y-Gtk3: Fix the hover color in the Nemo sidebar
  * Mint-Y: Add a light 1px border around window frames
  * Mint-Y: Bump up the color mix a bit
  * Mint-Y: Match up csd and non-csd window borders a bit better
  * Mint-Y: Hide shadows on tiled csd windows
  * Mint-Y: Improve the styling of the Caja filemanager
  * Mint-Y: Update the styling of the Thunar sidebar
  * Mint-Y: Fix the color of the Mate panel
  * Mint-Y: Clean up the titlebar styling some more
  * Mint-Y: Fix the size of csd titlebuttons
  * Mint-Y-Cinnamon: Adapt to the Cinnamon modal dialog theming changes
  * Mint-Y: Don't use the accent color in active buttons
  * Mint-Y: Fix the color of focus outline on active buttons
  * Mint-Y: Don't use the accent color for active menuitems
  * Fix test script
  * Mint-Y: Metacity, fix artefacts in close button.
  * Mint-Y: Don't special case sidebar scrollbars
  * Mint-Y: Readapt the csd titlebuttons to match metacity
  * Mint-Y: Fix corner radius of ssd window decorations
  * Remove tint on green theme and base color
  * Mint-Y-Dark: Fix the label color of events in gnome calendar
  * Mint-Y-Cinnamon: Add initial support for the reworked calendar applet
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8.8
  * use _libhandy.scss from Arc theme
* Mon Dec  7 2020 andy great <andythe_great@pm.me>
- Update to version 1.8.7.
  * Mint-Y - fix scale view context menu
  * Mint-X - fix scale view context menu background colour
  * Mint-Y-Cinnamon: Fix syntax error from previous commit
  * Mint-Y-Cinnamon: Remove padding from applet labels
  * Mint-Y-Metacity: Increase vertical "hit" area for titlebar
    buttons
  * Mint-X-Gtk: Restyle the menu separators a bit
  * Mint-Y themes: use em's instead of px's
* Mon Sep 28 2020 andy great <andythe_great@pm.me>
- Update to version 1.8.6.
  * Terminal: Make background fully opaque
- Update since 1.8.0.
  * Mint-X: Fix infobar colors
  * Revert "Update Orange color"
  * Revert "Update Grey color"
  * Revert "Update Purple Color"
  * Revert "Update Red color"
  * Revert "Update Teal color"
  * Revert "Update Sand color"
  * Revert "Update Blue color"
  * Revert "Update Aqua color"
  * Revert "Fix pink GTK2 dark menubars"
  * Revert "Factorize color codes into a single constants.py file"
  * Revert "Update Pink Color"
  * Factorize color codes into a single constants.py file
  * Covert to use sassc
  * Mint-Y-Cinnamon: Don't hardcode font sizes
  * Fix an error from the port to sassc
  * Mint-Y-Cinnamon: Update theming for the workspace and restart osd
  * Mint-X-Cinnamon: Remove hard coded font sizing
  * Mint-X-Cinnamon: Update theming for restart and workspace osd
  * Mint-X-Gtk3: Fix wrong colored headerbars
  * Mint-X-gtk3: Fix theming for GtkFlowBox and GtkFlowBoxChild
  * Mint-Y-Cinnamon: Improve the checkbox colors
  * update-variations: Accept a color as argument
  * Update variations: Fix re-creating dirs
  * Mint-Y-Gtk3: Fix the drag and drop target color
  * Mint-Y-Colors: new directory with files
  * Mint-Y-Grey: Fix the hover color of the window close button
  * update-variations: Don't modify GTK2 menubars
  * Mint-Y-Cinnamon: Tweak the look of GWL thumbnails
  * Update Pink Color
  * Factorize color codes into a single constants.py file
  * Fix pink GTK2 dark menubars
  * Update Aqua color
  * Update Blue color
  * Update Sand color
  * Update Teal color
  * Update Red color
  * Update Purple Color
  * Update Grey color
  * Update Orange color
  * Mint-Y: Update the theme for newer libsass
  * Linux Mint Cinnamon: Add styling for the media key osd level bar
  * Mint-X - fix theme not complying with apps request to set a monospace font
  * Remove about dialog styling from the cinnamon css
  * Gtk3: Add support for GtkStackSidebar needs attention
  * Use destructive/error color in stacksidebar needs-attention
  * Use selected_fg_color in stacksidebar needs-attention when it's selected
  * Mint-Y - Improve Cinnamon calendar menu's response to text scaling changes
  * Mint-Y: Fixes for Xfce 4.14
  * Mint-X: Xfce 4.14 fixes
  * Mint-Y: Darken xfwm4 titlebar text
  * Mint-Y: Darken xfwm4 buttons
  * Increase panel font size to 10pt in Mint-X and Linux Mint
  * Mint-Y-Dark(Cinnamon): Adjust accent color
  * Mint-Y: Darken terminal opacity 90%% -> 97%%
* Thu Sep  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.0 (changes since 1.7.8):
  * Mint X & Y - Keyboard applet & workspace-switcher simple fixes
    for vertical panels.
  * Mint-X: adjust for grouped-window-list-thumbnail-menu becoming
    active.
  * Mint X & Y - GWL - fix justification of label inherited from
    applet-box.
  * mint-Y: brighten tree view text 4 tints. Improves contrast.
  * Mint X & Y: adjust for grouped-window-list-thumbnail-menu
    becoming active.
  * Linux Mint: Update GWL borders.
  * Cinnamon: Switch fonts to Ubuntu 10.
  * Mint-Y: Switch GTK2 menus to dark.
  * Mint-Y: Contrast improvements.
  * Fix white pixel in src/Mint-Y/metacity-1/thumbnail-dark.png
  * Mint-Y: Don't use accent color for links.
  * Mint-Y: Fix active metacity button style.
  * Mint-Y: Increase contrast in progressbars.
  * Mint-Y: Give accent color slightly more saturation and
    less value.
  * Mint-Y: Use a lighter color for window titles in
    unfocused windows.
  * Mint-Y-Gtk3: Darken the dim-label color just a bit
  * Mint-Y-Cinnamon: Use larger fonts in the
    Cinnamon calendar applet.
  * Linux Mint: Use larger fonts in the calendar applet.
  * Mint-Y-Cinnamon: Tweak the calendar applet a bit more.
  * Mint-X - fix notification buttons on multi button notifications
  * Mint-Y: Darken terminal opacity 90%% -> 97%%
* Wed Dec 26 2018 sor.alexei@meowr.ru
- Update to version 1.7.8:
  * Mint-themes: Fix expo workspace entry not expanding to fit
    scaled fonts.
  * Mint-X & Mint-Y: Fix Attached Dialogue Titlebar.
  * Mint-Y-Grey*: Fix red GTK+2 menubar bg.
* Fri Dec 14 2018 sor.alexei@meowr.ru
- Update to version 1.7.6 (changes since 1.7.4):
  * Mint-X: Fix GWL styling in top/left/right panel orientations.
  * Cinnamon: Increase padding and centre align text in applets.
* Fri Nov 30 2018 sor.alexei@meowr.ru
- Update to version 1.7.4:
  * Update old class name.
  * Mint-X: Style new overview classes.
  * Linux Mint: Style new overview classes.
  * Mint-Y: Style new overview classes.
  * Mint-Y-Gtk3: Set some darker initial foreground colours.
  * Mint-Y: Darken window titles in the light variation.
  * Mint-Y-Gtk3: Bring back menu separators.
  * Mint-Y-Gtk3: Darken .dim-labels.
  * Mint-Y-Gtk3: Match the filechooser sidebar to the nemo sidebar
    colours.
  * Mint-Y-Gtk3: Darken the border on primary-toolbars.
  * Mint-Y-Gtk3: Darken header bar borders.
  * Mint-Y-Gtk3: More headerbar styling improvements.
  * Mint-Y-Gtk3: Fix the primary-toolbar border again.
  * Mint-Y-Cinnamon: Bump panel height to 40px.
  * Mint-Y-Gtk3: Use narrower titlebars.
  * Mint-X-Gtk3: Improve the titlebar styling.
  * Mint-X-Gtk3: Special case some headerbars.
  * Mint-Y-Gtk3: A few more improvements for muffin window
    decorations.
  * Add support for the grouped window list applet.
  * Mint-Y-Gtk3: Renegerate some css files.
  * Mint-Y-Cinnamon: Improve contrast in panels and menus.
  * Mint-X-Gtk3: Don't use pure white for file manager sidebar
    foregrounds.
  * Give the grouped window list applet unique class names.
  * Mint-Y-Cinnamon: Make the focused window in the grouped list
    more obvious.
  * Mint-Y-Cinnamon: Add menu separators.
  * Mint-Y-Gtk3: Fix the styling of GtkPaned wide separators.
  * Mint-Y-Cinnamon: Fix flashing white when hovering in the
    grouped window list.
  * git: Ignore sass cache files by extension.
  * Mint-Y-Gtk3: Improve the filechooser dialogue styling.
  * Mint-Y-Gtk3: Fix selected colours in the caja inactive
    treeview pane.
  * Mint-Y-Gtk3: Improve the filechooser theming a bit more.
  * Mint-Y-Cinnamon: Fix the menu search entry to work with larger
    text.
  * Gtk3: Fix support for drag and drop indication.
  * Style menu favourites buttons as squares.
  * Mint-X: Fix missing Cinnamon assets in Grey variation.
  * Start implementation of Mint-Y colour variations.
  * Colors: Overwrite assets.
  * Remove metacity colour variations.
  * Mint-Y: Remove xfce notify theme.
  * Mint-Y: Remove XFWM4 from Darker variant.
  * Colors: Start adding overrides.
  * Don't list Metacity colour deviations in Cinnamon.
  * Fix all GTK+ thumbnails and some Cinnamon thumbs.
  * Add a script to extract all the green colors used in Mint-Y.
  * Rename list-colors.py -> list-green-colors.py and let it accept
    a path.
  * list-green-colors: Count occurences.
  * Fix typo in colour code.
  * list-green-colors: Ignore success-color.
  * list-green-colors: Ignore more dummy colours.
  * Update generate-themes with new Mint-Y colours.
  * Add a colorize script (to change the hue of a png).
  * Update assets.
  * Update thumbnails.
  * Fix a couple of issues and regenerate assets.
  * Fix typo and regen assets.
  * Mint-Y-colors: Add close buttons for Xfce (xfwm4).
  * Mint-Y: Fix the thumbnails for the darker variations.
  * Mint-Y-Cinnamon: Fix the styling of vertical applet separators.
  * Mint-Y: Improve close-prelight button in gtk-3.
  * render-assets-script: Fix dpi for Mint19 inkscape.
  * Mint-Y-variations: Update scripts.
  * Mint-Y: Make sure we update the dark version within the -Darker
    variations.
  * Add mint-y palette.
  * Add support for GWL number badges.
  * Fix Cinnamon tiling colour in colour variations.
  * Mint-Y-colors: Add missing xfwm4 close buttons.
* Mon Sep 24 2018 sor.alexei@meowr.ru
- Update to version 1.7.3:
  * Gtk3: Properly place the "grab" area for pane separators.
* Fri Jul 20 2018 sor.alexei@meowr.ru
- Update to version 1.7.2:
  * Mint-X-Gtk3: Restore the Mint 18.3 styling of the mate-panel
    taskbar.
  * Mint-Y-Gtk3: Fix atril toolbar in the darker variation.
  * Gtk3: Remove a white border from the nemo sidebar.
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.7.1 (changes since 1.6.9):
  * debian: Add ruby-sass to build-deps.
- Add rubygem(sass) to BuildRequires.
* Sun Jun 17 2018 sor.alexei@meowr.ru
- Update to version 1.6.9:
  * Gtk3: Add theming for MATE osd window when Marco with
    compositing is enabled.
  * Mint-X-Gtk3: Fix the colour of some more selected labels.
  * Mint-X-metacity: Fix black border on focused titlebars under
    hidpi.
  * Mint-X-Gtk3: Fix a couple of issues with slick-greeter.
* Wed Jun  6 2018 sor.alexei@meowr.ru
- Update to version 1.6.8 (changes since 1.6.6):
  * Mint-X-Gtk3: Colour non-empty levelbar blocks.
  * Mint-X-Gtk3: Fix a few issues from 1.6.6.
  * Mint-X-Gtk3: Fix weirdness when hovering treeviews.
  * Gtk3: Add theming for Marco tooltips.
  * Mint-X: Fix rubberband style.
  * Cleanup Caja tabs.
  * Restore top scroll indicator in pluma.
  * Mint-X-Gtk3: More tab alignment fixes.
  * Mint-Y-Gtk3: Fix selected item colours in the Nemo inactive
    view.
  * Mint-X-Gtk3: Fix transparent background in mate-terminal.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.6.6:
  * Mint-X: Align tabs, application specific tab colouring, restore
    caja sidebar colour, improve pane separator.
* Tue May 22 2018 sor.alexei@meowr.ru
- Update to version 1.6.5:
  * Improve window-list progress.
* Thu May 17 2018 sor.alexei@meowr.ru
- Update to version 1.6.4:
  * Mint-X-Cinnamon: Remove some unneeded icons sizes.
  * Mint-X-Cinnamon: Theme the level bar in the volume OSD.
  * Linux Mint: Remove some unneeded icons sizes.
  * Mint-X-Cinnamon: Fix colour of selected window in the
    workspace switcher.
  * Mint-Y-Gtk3: Improve infobar insensitive colours.
  * Mint-X GTK-3 "Character Palette" applet background.
  * Set background colour in MATE terminal.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.6.3:
  * Mint-Y-Cinnamon: Use the selected_bg_color in menus.
  * Mint-Y-Cinnamon: Fix the styling of the sound applet.
  * Mint-Y-Gtk2: Use selected_bg_color in menus.
  * Mint-Y-Cinnamon: Fix the size of the main menu applet entry.
* Sat Apr 28 2018 sor.alexei@meowr.ru
- Update to version 1.6.2:
  * Remove an accidentally included directory from Mint-Y.
  * Mint-Y: Add some theming for slick greeter.
  * Mint-Y: Quiet a couple warnings in the gtk3 theme from unused
    properties.
  * Mint-X, Mint-Y: Add window-list-preview.
  * Mint-Y-Cinnamon: Small cleanup for the window list preview.
  * Mint-Y-Cinnamon: Clean up panel launcher placement.
  * Mint-Y: Make a few improvements for mate-panel.
  * Mint-Y-Cinnamon: Clean up a bunch of unused variables.
  * Mint-Y-Gtk3: Improve the styling of the list box header in Mint
    settings windows.
  * Mint-Y-Gtk3: Improve the hover effect on listbox rows.
  * Mint-Y-Gtk3: Fix the background color of the stacksidebar
    listbox.
  * Mint-Y-Gtk3: Fix the color of the sidebar in GtkFileChooser.
  * Mint-Y-Gtk3: Make sure circular buttons are actually circular.
  * Linux Mint: Add window-list-preview class.
  * Mint-X-Gtk3: Start updating for gtk3.22
  * Mint-X-Gtk3: Fix theming of wide paned vertical separators.
  * [Mint-X/Cinnamon] Cleanup and fixes.
  * Mint-X-Gtk3: Clean up the styling of cinnamon-apps a bit.
  * Mint-X-Gtk3: Quiet the remaining warnings.
  * Mint-X-Gtk3: Improve check and radio items a bit.
  * Mint-X-Gtk3: Add some basic theming for GtkExpander.
  * Mint-X-Gtk3: Clean up treeviews a bit.
  * Mint-X-Gtk3: Fix a weird border on menus.
  * Mint-X-Gtk3: Fix the style of popover menu items.
  * Mint-X-Gtk3: Do some more small cleanups.
  * Mint-X-Gtk3: Fix a double border on paned sidebars.
  * Mint-X-Gtk3: Add theming for terminal and xed.
  * Mint-X-Gtk3: Hide separator in file and font buttons.
  * Mint-X-Gtk3: Fix styling of the appmenu button.
  * Mint-X-Gtk3: Remove unused pix theming.
  * Mint-X-Gtk3: Add styling for nemo rename entries.
  * Mint-X-Gtk3: Improve some insensitive icon and label colours.
  * Mint-X-Gtk3: Fix theming for GtkCalendar.
  * Mint-X-Gtk3: Clean up some commented out garbage.
  * Mint-X-Gtk3: Fix GtkAssistant styling.
  * Mint-Y: Correct font to font-size in window list preview.
  * Mint-X-Gtk3: Fix the styling for GtkColorChooser.
  * Mint-X-Gtk3: Update some theming for content views.
  * Remove unused style and unused images.
  * Styling homogenisation.
  * Mint-X-Gtk3: Add assets for header/titlebar window controls.
  * Mint-X-Gtk3: Update theming for lightdm.
  * Mint-X-Gtk3: Remove unused asset images.
  * Mint-X-Gtk3: Update infobar styling.
  * Mint-X-Gtk3: Fix toolbar padding.
  * [Mint-X/Cinnamon] Cleanup and fixes.
  * Mint-X-Gtk3: Fix some header/titlebar padding issues.
  * Mint-X-Gtk3: Add support for GtkShortcutsWindow.
  * Mint-Y-Gtk3: Fix oversized tabs in places like gnome terminal
    notebooks.
  * Mint-Y-Gtk3: Add back just a bit of padding to buttons in
    terminal headers.
  * Mint-Y-Gtk3: Fix disabled colors in dark header/toolbars.
  * [Mint-X/Cinnamon] Fix modal dialogues button shifting when
    buttons are focused.
  * Mint-X-Gtk3: Fix a few random selectors.
  * Mint-X-Gtk3: Add some catch all selectors for selected items.
  * Mint-Y-Gtk3: Adapt to the changes in the nemo sidebar.
  * Mint-Y-Gtk3: Couple of nemo improvements.
  * Mint-Y-Gtk3: Use a dark sidebar in caja.
  * Mint-Y-Gtk3: Update some xfce4 panel theming.
  * Mint-Y: More Xfce4 panel fixes.
  * Mint-Y: Add sticky/shade/menu icons.
  * Mint-Y-Cinnamon: Use Noto Sans as the base font.
  * Mint-X-Gtk3: Clean up a couple of errors and unused selectors.
  * Mint-Y-Gtk3: Fix the Nemo sidebar separator.
  * Cinnamon: Sound applet player buttons.
  * Cinnamon: window-list modifications in LM theme.
  * Mint-Y-Gtk3: Improve the styling of the linked entry in
    mintinstall.
  * Mint-X*: Improve assets and progress colours.
  * Mint-X-Gtk3: Fix the colour of buttons inside of infobars.
  * All-Gtk3: Add proper support for GtkTreeview dnd.
  * Clean up unused styles.
  * Some fixes.
* Thu Mar 15 2018 sor.alexei@meowr.ru
- Update to version 1.6.1 (changes since 1.5.0):
  * Remove duplicated files, generate colour variations during the
    build.
  * Add Mint-X GTK+3 and Mint-Y.
  * Add Cinnamon themes.
- Obsolete cinnamon-themes in metatheme-mint-common.
- Recommend mint-y-icon-theme in metatheme-mint-common for Mint-Y.
* Thu May  4 2017 sor.alexei@meowr.ru
- Update to version 1.5.0 (changes since 1.4.8):
  * metacity-theme-2.xml: Fill the titlebar underneath the gradient.
  * metacity-2: Improve styling for border type windows.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.4.8:
  * Fix mintmenu background picture.
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Update to version 1.4.7:
  * Metacity: Round corners in border style.
* Sun Nov  8 2015 sor.alexei@meowr.ru
- Update to version 1.4.6:
  * Xfce logout improvements.
  * Remove extra themes.
  * Pressed colour is inherited from style.
  * Add Xfwm compact theme.
  * Pressed buttons have shade and close button is rounded.
  * Fix fill icons (it was 17x18 size, now 16x16 as it should be).
  * 1000 new icons.
  * Chromium r-click menu unclickable items gray.
  * Separate libreoffice-style-mint.
- Drop libreoffice-icon-theme-mint package.
* Sat Oct 17 2015 sor.alexei@meowr.ru
- Update to version 1.4.5 (changes since 1.3.9+git20141119):
  * Reduce file size of svg images.
  * Update LibreOffice theme (compatible with LO 4.3 and 4.4).
  * Add a metacity-2 theme for MATE 1.10+.
  * Re-work the window control icons a bit to improve sharpness and
    definition.
  * Add a grey version of the Gtk2 theme.
  * Add themeing for Xfce alt-tab and notifications.
- Spec redone.
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2014.11.19 from git
* Mon Jun  2 2014 stefan@fam-elser.de
- Initial build
